8231598: keytool does not export sun.security.mscapi
authorweijun
Thu, 24 Oct 2019 15:53:20 +0800
changeset 58776 ea153023d832
parent 58775 ba524a5f7cc2
child 58777 18c246ad2ff9
8231598: keytool does not export sun.security.mscapi Reviewed-by: mullan
src/java.base/share/classes/sun/security/tools/KeyStoreUtil.java
test/jdk/sun/security/mscapi/ProviderClassOption.java
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/test/jdk/sun/security/mscapi/ProviderClassOption.java	Thu Oct 24 15:53:20 2019 +0800
@@ -0,0 +1,40 @@
+/*
+ * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.
+ *
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
+ *
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
+ */
+
+/*
+ * @test
+ * @bug 8231598
+ * @requires os.family == "windows"
+ * @library /test/lib
+ * @summary keytool does not export sun.security.mscapi
+ */
+
+import jdk.test.lib.SecurityTools;
+
+public class ProviderClassOption {
+    public static void main(String[] args) throws Throwable {
+        SecurityTools.keytool("-v -storetype Windows-ROOT -list"
+                + " -providerClass sun.security.mscapi.SunMSCAPI")
+            .shouldHaveExitValue(0);
+    }
+}
--- a/src/java.base/share/classes/sun/security/tools/KeyStoreUtil.java	Thu Oct 24 09:57:29 2019 +0200
+++ b/src/java.base/share/classes/sun/security/tools/KeyStoreUtil.java	Thu Oct 24 15:53:20 2019 +0800
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2005, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -304,14 +304,17 @@
     public static void loadProviderByClass(
             String provClass, String arg, ClassLoader cl) {
 
         // For compatibility, SunPKCS11 and OracleUcrypto can still be
         // loadable with -providerClass.
         if (provClass.equals("sun.security.pkcs11.SunPKCS11")) {
             loadProviderByName("SunPKCS11", arg);
             return;
         } else if (provClass.equals("com.oracle.security.crypto.UcryptoProvider")) {
             loadProviderByName("OracleUcrypto", arg);
             return;
+        } else if (provClass.equals("sun.security.mscapi.SunMSCAPI")) {
+            loadProviderByName("SunMSCAPI", arg);
+            return;
         }
 
         Provider prov;
@@ -304,14 +304,17 @@
             String provClass, String arg, ClassLoader cl) {
 
-        // For compatibility, SunPKCS11 and OracleUcrypto can still be
-        // loadable with -providerClass.
+        // For compatibility, SunPKCS11, OracleUcrypto, and SunMSCAPI
+        // can still be loadable with -providerClass.
         if (provClass.equals("sun.security.pkcs11.SunPKCS11")) {
             loadProviderByName("SunPKCS11", arg);